@@ -11,13 +11,11 @@ from impy._types import Dims
 from ._utils import _deconv, _filters
 from ._utils._skimage import _get_ND_butterworth_filter
 
-from dask import array as da
-
 _T = TypeVar("_T", bound=AxesMixin)
 Boundary = Literal["reflect", "periodic", "nearest", "none"]
 
 class TiledAccessor(Generic[_T]):
-    def __get__(self, instance: _T, owner: type[_T]) -> _PartialTiledImage[_T]:
+    def __get__(self, instance: _T, owner: type[_T] | None = None) -> _PartialTiledImage[_T]:
         if instance is None:
             return self
         return _PartialTiledImage(instance)
@@ -33,7 +31,7 @@ class _PartialTiledImage(Generic[_T]):
         overlap: int | tuple[int, ...] = 32,
         boundary: Boundary | list[Boundary] = "reflect",
         dims: Dims = None,
-    ) -> TiledImage:
+    ) -> TiledImage[_T]:
         img = self._img()
         if img is None:
             raise RuntimeError("Image has been deleted")
@@ -93,6 +91,8 @@ class TiledImage(Generic[_T]):
 
         img = self._deref_image()
         if isinstance(img, ImgArray):
+            from dask import array as da
+            
             input = da.from_array(img.value, chunks=self._chunks)
             out: np.ndarray = xp.asnumpy(
                 da.map_overlap(
